
import argparse


def get_parser_args():
    '''This creates a parser and is invoked from main program.

    Args:
        None
    Returns:
        Parsed args object.
    Raises:
        None

    '''

    parser = argparse.ArgumentParser(description='Get Surgeo arguments.')
    # File argumets
    parser.add_argument('--file',
                        nargs=2,
                        help='Takes input file and output file as arguments.',
                        dest='file')
    # Simple arguments
    parser.add_argument('--simple',
                        nargs=2,
                        help='Takes zip and surname, returns string.',
                        dest='simple')
    # Complex arguments
    parser.add_argument('--complex',
                        nargs=2,
                        help='Takes zip and name, returns csv string.',
                        dest='complex')
    # Pipe argument
    parser.add_argument('--pipe',
                        action='store_true',
                        help='Takes no arguments. Used only for piping.',
                        dest='pipe')
    # Setup argument
    parser.add_argument('--setup',
                        action='store_true',
                        help='Takes no inputs and sets up database.',
                        dest='setup')
    #parse and return args
    parsed_args = parser.parse_args()
    return parsed_args



#!/usr/local/bin/python3
#coding: utf-8

from distutils.core import setup
from distutils.core import DistutilsError

setup(name='surgeo',
      version='0.6.6',
      description='Disparate impact testing and surname geocoding analysis',
      url='https://github.com/theonaun/surgeo',
      author='Theo Naunheim',
      author_email='theonaunheim@gmail.com',
      license='MIT',
      packages=['surgeo', 'surgeo.db', 'surgeo.model', 'surgeo.utilities'],
      classifiers=['Development Status :: 4 - Beta',
                   'Intended Audience :: Financial and Insurance Industry',
                   'License :: OSI Approved :: MIT License',
                   'Natural Language :: English',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python :: 3',
                   'Topic :: Office/Business :: Financial']
      )
